==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/materiallist_001/MaterialList.java <==

package net.datastream.schemas.mp_entities.materiallist_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.COMMENT_Type;
import net.datastream.schemas.mp_fields.MATERIALLISTID_Type;
import net.datastream.schemas.mp_fields.REVISIONCONTROL_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTCOMMENTS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REVISIONCONTROL" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       &lt;attribute name="numberofpartlines" type="{http://www.w3.org/2001/XMLSchema}long" default="0" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "materiallistid",
    "activityid",
    "userdefinedarea",
    "status",
    "materiallistcomments",
    "classid",
    "revisioncontrol"
})
@XmlRootElement(name = "MaterialList")
public class MaterialList {

    @XmlElement(name = "MATERIALLISTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected MATERIALLISTID_Type materiallistid;
    @XmlElement(name = "ACTIVITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYID activityid;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "MATERIALLISTCOMMENTS", namespace = "http://schemas.datastream.net/MP_fields")
    protected COMMENT_Type materiallistcomments;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "REVISIONCONTROL", namespace = "http://schemas.datastream.net/MP_fields")
    protected REVISIONCONTROL_Type revisioncontrol;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "numberofpartlines")
    protected Long numberofpartlines;

    /**
     * Obtient la valeur de la propriété materiallistid.
     * 
     * @return
     *     possible object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public MATERIALLISTID_Type getMATERIALLISTID() {
        return materiallistid;
    }

    /**
     * Définit la valeur de la propriété materiallistid.
     * 
     * @param value
     *     allowed object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public void setMATERIALLISTID(MATERIALLISTID_Type value) {
        this.materiallistid = value;
    }

    /**
     * Obtient la valeur de la propriété activityid.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Définit la valeur de la propriété activityid.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedarea.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Définit la valeur de la propriété userdefinedarea.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Obtient la valeur de la propriété status.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Définit la valeur de la propriété status.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Obtient la valeur de la propriété materiallistcomments.
     * 
     * @return
     *     possible object is
     *     {@link COMMENT_Type }
     *     
     */
    public COMMENT_Type getMATERIALLISTCOMMENTS() {
        return materiallistcomments;
    }

    /**
     * Définit la valeur de la propriété materiallistcomments.
     * 
     * @param value
     *     allowed object is
     *     {@link COMMENT_Type }
     *     
     */
    public void setMATERIALLISTCOMMENTS(COMMENT_Type value) {
        this.materiallistcomments = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété revisioncontrol.
     * 
     * @return
     *     possible object is
     *     {@link REVISIONCONTROL_Type }
     *     
     */
    public REVISIONCONTROL_Type getREVISIONCONTROL() {
        return revisioncontrol;
    }

    /**
     * Définit la valeur de la propriété revisioncontrol.
     * 
     * @param value
     *     allowed object is
     *     {@link REVISIONCONTROL_Type }
     *     
     */
    public void setREVISIONCONTROL(REVISIONCONTROL_Type value) {
        this.revisioncontrol = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Obtient la valeur de la propriété numberofpartlines.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public long getNumberofpartlines() {
        if (numberofpartlines == null) {
            return  0L;
        } else {
            return numberofpartlines;
        }
    }

    /**
     * Définit la valeur de la propriété numberofpartlines.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setNumberofpartlines(Long value) {
        this.numberofpartlines = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/materiallist_001/MaterialList.java <==

package net.datastream.schemas.mp_entities.materiallist_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.ACTIVITYID;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.COMMENT_Type;
import net.datastream.schemas.mp_fields.MATERIALLISTID_Type;
import net.datastream.schemas.mp_fields.REVISIONCONTROL_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ACTIVITYID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MATERIALLISTCOMMENTS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REVISIONCONTROL" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *       <attribute name="numberofpartlines" type="{http://www.w3.org/2001/XMLSchema}long" default="0" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "materiallistid",
    "activityid",
    "userdefinedarea",
    "status",
    "materiallistcomments",
    "classid",
    "revisioncontrol"
})
@XmlRootElement(name = "MaterialList")
public class MaterialList {

    @XmlElement(name = "MATERIALLISTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected MATERIALLISTID_Type materiallistid;
    @XmlElement(name = "ACTIVITYID", namespace = "http://schemas.datastream.net/MP_fields")
    protected ACTIVITYID activityid;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "MATERIALLISTCOMMENTS", namespace = "http://schemas.datastream.net/MP_fields")
    protected COMMENT_Type materiallistcomments;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "REVISIONCONTROL", namespace = "http://schemas.datastream.net/MP_fields")
    protected REVISIONCONTROL_Type revisioncontrol;
    @XmlAttribute(name = "recordid")
    protected Long recordid;
    @XmlAttribute(name = "numberofpartlines")
    protected Long numberofpartlines;

    /**
     * Gets the value of the materiallistid property.
     * 
     * @return
     *     possible object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public MATERIALLISTID_Type getMATERIALLISTID() {
        return materiallistid;
    }

    /**
     * Sets the value of the materiallistid property.
     * 
     * @param value
     *     allowed object is
     *     {@link MATERIALLISTID_Type }
     *     
     */
    public void setMATERIALLISTID(MATERIALLISTID_Type value) {
        this.materiallistid = value;
    }

    /**
     * Gets the value of the activityid property.
     * 
     * @return
     *     possible object is
     *     {@link ACTIVITYID }
     *     
     */
    public ACTIVITYID getACTIVITYID() {
        return activityid;
    }

    /**
     * Sets the value of the activityid property.
     * 
     * @param value
     *     allowed object is
     *     {@link ACTIVITYID }
     *     
     */
    public void setACTIVITYID(ACTIVITYID value) {
        this.activityid = value;
    }

    /**
     * Gets the value of the userdefinedarea property.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Sets the value of the userdefinedarea property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Gets the value of the status property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Sets the value of the status property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Gets the value of the materiallistcomments property.
     * 
     * @return
     *     possible object is
     *     {@link COMMENT_Type }
     *     
     */
    public COMMENT_Type getMATERIALLISTCOMMENTS() {
        return materiallistcomments;
    }

    /**
     * Sets the value of the materiallistcomments property.
     * 
     * @param value
     *     allowed object is
     *     {@link COMMENT_Type }
     *     
     */
    public void setMATERIALLISTCOMMENTS(COMMENT_Type value) {
        this.materiallistcomments = value;
    }

    /**
     * Gets the value of the classid property.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Sets the value of the classid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Gets the value of the revisioncontrol property.
     * 
     * @return
     *     possible object is
     *     {@link REVISIONCONTROL_Type }
     *     
     */
    public REVISIONCONTROL_Type getREVISIONCONTROL() {
        return revisioncontrol;
    }

    /**
     * Sets the value of the revisioncontrol property.
     * 
     * @param value
     *     allowed object is
     *     {@link REVISIONCONTROL_Type }
     *     
     */
    public void setREVISIONCONTROL(REVISIONCONTROL_Type value) {
        this.revisioncontrol = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

    /**
     * Gets the value of the numberofpartlines property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public long getNumberofpartlines() {
        if (numberofpartlines == null) {
            return  0L;
        } else {
            return numberofpartlines;
        }
    }

    /**
     * Sets the value of the numberofpartlines property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setNumberofpartlines(Long value) {
        this.numberofpartlines = value;
    }

}
